embassy-crypto-driver

Crates

git

Versions

default

Flavors

Aes256CcmImpl

Struct Aes256CcmImpl 

pub struct Aes256CcmImpl;
The global Aes256Ccm implementation.

Implementations

Source

impl Aes256CcmImpl

pub fn init(key: &[u8; 32]) -> Aes256CcmImplContext

Initialize with a 256-bit key.

pub fn encrypt( ctx: &Aes256CcmImplContext, nonce: &[u8], aad: &[u8], buffer: InOutBuf<'_, '_, u8>, tag: &mut [u8], ) -> Result<(), CryptoError>

Encrypt plaintext in-place and produce an authentication tag. The tag length is determined by the length of the tag slice.

pub fn decrypt( ctx: &Aes256CcmImplContext, nonce: &[u8], aad: &[u8], buffer: InOutBuf<'_, '_, u8>, tag: &[u8], ) -> Result<(), CryptoError>

Decrypt ciphertext in-place and verify an authentication tag. The tag length is determined by the length of the tag slice.