embassy-crypto-driver

Crates

git

Versions

default

Flavors

Aes256Ccm

Trait Aes256Ccm 

pub trait Aes256Ccm {
    type Context: Clone;

    // Required methods
    fn init(key: &[u8; 32]) -> Self::Context;
    fn encrypt(
        ctx: &Self::Context,
        nonce: &[u8],
        aad: &[u8],
        buffer: InOutBuf<'_, '_, u8>,
        tag: &mut [u8],
    ) -> Result<(), CryptoError>;
    fn decrypt(
        ctx: &Self::Context,
        nonce: &[u8],
        aad: &[u8],
        buffer: InOutBuf<'_, '_, u8>,
        tag: &[u8],
    ) -> Result<(), CryptoError>;
}
AES-256 CCM AEAD trait.

The tag and nonce sizes are validated at runtime by the HAL.

Required Associated Types

type Context: Clone

Opaque storage for the implementation’s key schedule.

Required Methods

fn init(key: &[u8; 32]) -> Self::Context

Initialize with a 256-bit key.

fn encrypt( ctx: &Self::Context, nonce: &[u8], aad: &[u8], buffer: InOutBuf<'_, '_, u8>, tag: &mut [u8], ) -> Result<(), CryptoError>

Encrypt plaintext in-place and produce an authentication tag. The tag length is determined by the length of the tag slice.

fn decrypt( ctx: &Self::Context, nonce: &[u8], aad: &[u8], buffer: InOutBuf<'_, '_, u8>, tag: &[u8], ) -> Result<(), CryptoError>

Decrypt ciphertext in-place and verify an authentication tag. The tag length is determined by the length of the tag slice.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors